@@ -20,7 +20,8 @@
 #'
 #' @export
 #' @importFrom stats nobs
-#'
+#' @import cli
+#' 
 
 
 summ <- function(model, ...) {
@@ -396,7 +397,6 @@ summ.lm <- function(
 ### PRINT METHOD
 
 #' @export
-#' @importFrom crayon underline inverse italic
 
 print.summ.lm <- function(x, ...) {
 
@@ -413,11 +413,11 @@ print.summ.lm <- function(x, ...) {
   }
 
   if (x$model.fit == TRUE && !is.null(x$modpval)) {
-    stats <- paste(italic("F"), "(", x$fnum, ",", x$fden, ") = ",
-        num_print(x$fstat, digits = x$digits), ", ", italic("p"), " = ",
+    stats <- paste(style_italic("F"), "(", x$fnum, ",", x$fden, ") = ",
+        num_print(x$fstat, digits = x$digits), ", ", style_italic("p"), " = ",
         num_print(x$modpval, digits = x$digits), "\n",
-        italic("R\u00B2 = "), num_print(x$rsq, digits = x$digits), "\n",
-        italic("Adj. R\u00B2 = "), num_print(x$arsq, digits = x$digits),
+        style_italic("R\u00B2 = "), num_print(x$rsq, digits = x$digits), "\n",
+        style_italic("Adj. R\u00B2 = "), num_print(x$arsq, digits = x$digits),
         sep = "")
     print_mod_fit(stats)
   }
@@ -442,12 +442,7 @@ print.summ.lm <- function(x, ...) {
 #' @param options Chunk options.
 #' @param ... Ignored.
 #' @rdname knit_print.summ
-#' @rawNamespace 
-#' if (getRversion() >= "3.6.0") {
-#'   S3method(knitr::knit_print, summ.lm)
-#' } else {
-#'   export(knit_print.summ.lm)
-#' }
+#' @exportS3Method knitr::knit_print
 
 knit_print.summ.lm <- function(x, options = NULL, ...) {
 
@@ -851,9 +846,9 @@ print.summ.glm <- function(x, ...) {
       type <- "Linear regression"
     } else {
       type <- paste("Generalized linear model\n ",
-                    italic("Family:"),
+                    style_italic("Family:"),
                     as.character(x$lmFamily[1]), "\n ",
-                    italic("Link function:"),
+                    style_italic("Link function:"),
                     as.character(x$lmFamily[2]), sep = " ")
     }
     print_mod_info(missing = x$missing, n = x$n, dv = x$dv, type = type)
@@ -862,13 +857,13 @@ print.summ.glm <- function(x, ...) {
   if (x$model.fit == TRUE) {
     stats <- paste("\u03C7\u00B2(",
                   x$chisq$df,  ") = ", num_print(x$chisq$chi, x$digits), ", ",
-                  italic("p"), " = ", num_print(x$chisq$p, x$digits), "\n",
-                   italic("Pseudo-R\u00B2 (Cragg-Uhler)"), " = ",
+                  style_italic("p"), " = ", num_print(x$chisq$p, x$digits), "\n",
+                   style_italic("Pseudo-R\u00B2 (Cragg-Uhler)"), " = ",
                    num_print(x$rsq, digits = x$digits), "\n",
-                   italic("Pseudo-R\u00B2 (McFadden)"), " = ",
+                   style_italic("Pseudo-R\u00B2 (McFadden)"), " = ",
                    num_print(x$rsqmc, digits = x$digits), "\n",
-                   italic("AIC"), " = ", num_print(x$aic, x$digits),
-                   ", ", italic("BIC"), " = ", num_print(x$bic, x$digits),
+                   style_italic("AIC"), " = ", num_print(x$aic, x$digits),
+                   ", ", style_italic("BIC"), " = ", num_print(x$bic, x$digits),
                    sep = "")
     print_mod_fit(stats)
   }
@@ -893,12 +888,7 @@ print.summ.glm <- function(x, ...) {
 
 
 #' @rdname knit_print.summ
-#' @rawNamespace 
-#' if (getRversion() >= "3.6.0") {
-#'   S3method(knitr::knit_print, summ.glm)
-#' } else {
-#'   export(knit_print.summ.glm)
-#' }
+#' @exportS3Method knitr::knit_print
 
 knit_print.summ.glm <- function(x, options = NULL, ...) {
 
@@ -964,10 +954,12 @@ knit_print.summ.glm <- function(x, options = NULL, ...) {
       chi <- "chi\u00B2("
     }
     stats <- data.frame(stat = c(paste0(chi, x$chisq$df,  ")"),
+                                  "p",
                                  "Pseudo-R\u00B2 (Cragg-Uhler)",
                                  "Pseudo-R\u00B2 (McFadden)",
                                  "AIC", "BIC"),
                         value = c(num_print(x$chisq$chi, x$digits),
+                                  num_print(x$chisq$p, x$digits),
                                   num_print(x$rsq, digits = x$digits),
                                   num_print(x$rsqmc, digits = x$digits),
                                   num_print(x$aic, x$digits),
@@ -1338,8 +1330,8 @@ print.summ.svyglm <- function(x, ...) {
     } else {
       # Otherwise just treat it like glm
       type <- paste("Analysis of complex survey design", "\n",
-                  italic("Family:"), as.character(x$lmFamily[1]),
-                  "\n", italic("Link function:"), as.character(x$lmFamily[2]),
+                  style_italic("Family:"), as.character(x$lmFamily[1]),
+                  "\n", style_italic("Link function:"), as.character(x$lmFamily[2]),
                   sep = " ")
     }
     print_mod_info(missing = x$missing, n = x$n, dv = x$dv, type = type)
@@ -1349,17 +1341,17 @@ print.summ.svyglm <- function(x, ...) {
     if (as.character(x$lmFamily[1]) == "gaussian" &&
         as.character(x$lmFamily[2]) == "identity") {
       # If it's a linear model, show regular lm fit stats
-      stats <- paste(italic("R\u00B2"), " = ",
+      stats <- paste(style_italic("R\u00B2"), " = ",
                      num_print(x$rsq, digits = x$digits), "\n",
-                     italic("Adj. R\u00B2"), " = ",
+                     style_italic("Adj. R\u00B2"), " = ",
                      num_print(x$arsq, digits = x$digits), sep = "")
     } else {
       # If it isn't linear, show GLM fit stats
-      stats <- paste(italic("Pseudo-R\u00B2 (Cragg-Uhler)"), " = ",
+      stats <- paste(style_italic("Pseudo-R\u00B2 (Cragg-Uhler)"), " = ",
                      num_print(x$rsq, digits = x$digits), "\n",
-                     italic("Pseudo-R\u00B2 (McFadden)"), " = ",
+                     style_italic("Pseudo-R\u00B2 (McFadden)"), " = ",
                      num_print(x$rsqmc, digits = x$digits), "\n",
-                     italic("AIC"), " = ", num_print(x$aic, x$digits), sep = "")
+                     style_italic("AIC"), " = ", num_print(x$aic, x$digits), sep = "")
     }
     print_mod_fit(stats)
   }
@@ -1385,12 +1377,7 @@ print.summ.svyglm <- function(x, ...) {
 }
 
 #' @rdname knit_print.summ
-#' @rawNamespace 
-#' if (getRversion() >= "3.6.0") {
-#'   S3method(knitr::knit_print, summ.svyglm)
-#' } else {
-#'   export(knit_print.summ.svyglm)
-#' }
+#' @exportS3Method knitr::knit_print
 
 knit_print.summ.svyglm <- function(x, options = NULL, ...) {
 
@@ -1680,6 +1667,7 @@ knit_print.summ.svyglm <- function(x, options = NULL, ...) {
 #'
 #' @importFrom stats coef coefficients lm predict sd cooks.distance pf logLik
 #'  AIC BIC family fitted pt residuals terms model.weights
+#' @importFrom rlang check_installed is_installed
 #' @export
 #' @aliases j_summ.merMod
 #'
@@ -1759,15 +1747,16 @@ summ.merMod <- function(
         if (requireNamespace("lmerTest", quietly = TRUE)) {
           satt <- TRUE
         } else {
-          stop_wrap("You have requested Satterthwaite p values but you do
-                    not have the lmerTest package installed.")
+          check_installed("lmerTest", reason =
+            "The lmerTest package is required for Satterthwaite d.f.")
         }
       } else if (t.df %in% c("k-r", "kenward-roger", "Kenward-Roger")) {
         if (requireNamespace("pbkrtest", quietly = TRUE)) {
           pbkr <- TRUE
         } else {
-          stop_wrap("You have requested Kenward-Roger p values but you do
-                    not have the pbkrtest package installed.")
+          check_installed("pbkrtest", reason =
+            "The pbkrtest package is required for Kenward-Roger d.f."
+          )
         }
       } else if (is.numeric(t.df) || t.df %in% c("resid", "residual")) {
         manual_df <- TRUE
@@ -2006,29 +1995,29 @@ print.summ.merMod <- function(x, ...) {
       type <- "Mixed effects linear regression"
     } else {
       type <- paste("Mixed effects generalized linear regression", "\n",
-                    italic("Error Distribution: "),
+                    style_italic("Error Distribution: "),
                     as.character(x$lmFamily[1]), "\n",
-                    italic("Link function: "), as.character(x$lmFamily[2]),
+                    style_italic("Link function: "), as.character(x$lmFamily[2]),
                     sep = "")
     }
     print_mod_info(missing = x$missing, n = x$n, dv = x$dv, type = type)
   }
 
   if (x$model.fit == T) {
-    stats <- paste(italic("AIC"), " = ", num_print(x$aic, x$digits),
-                   ", ", italic("BIC"), " = ",
+    stats <- paste(style_italic("AIC"), " = ", num_print(x$aic, x$digits),
+                   ", ", style_italic("BIC"), " = ",
                    num_print(x$bic, x$digits), sep = "")
     if (x$r.squared == TRUE) {
-      stats <- paste(stats, "\n", italic("Pseudo-R\u00B2 (fixed effects)"),
+      stats <- paste(stats, "\n", style_italic("Pseudo-R\u00B2 (fixed effects)"),
                      " = ", num_print(x$rsq$Marginal, x$digits), "\n",
-                     italic("Pseudo-R\u00B2 (total)"), " = ",
+                     style_italic("Pseudo-R\u00B2 (total)"), " = ",
                      num_print(x$rsq$Conditional, x$digits), sep = "")
     }
     print_mod_fit(stats)
   }
 
   if (x$model.coefs == TRUE) {
-    cat(underline("FIXED EFFECTS:\n"))
+    cat(style_underline("FIXED EFFECTS:\n"))
     print(md_table(ctable, format = getOption("summ.table.format", "multiline"),
                   sig.digits = FALSE, digits = x$digits))
     
@@ -2037,8 +2026,8 @@ print.summ.merMod <- function(x, ...) {
 
       if (x$p_calc == "residual") {
 
-        cat(italic$cyan("\nNote: p values calculated based on residual d.f. =",
-            x$df, "\n"))
+        cat(style_italic(col_cyan(
+           "\nNote: p values calculated based on residual d.f. =", x$df, "\n")))
 
         if (is.null(x$t.df)) {
           msg_wrap("Using p values with lmer based on residual d.f. may inflate
@@ -2050,18 +2039,18 @@ print.summ.merMod <- function(x, ...) {
       } else if (x$p_calc %in% c("k-r", "Kenward-Roger", "kenward-roger")) {
 
         cat("\n")
-        cat_wrap(italic$cyan("p values calculated using Kenward-Roger standard
-                            errors and d.f."), brk = "\n")
+        cat_wrap(style_italic(col_cyan("p values calculated using Kenward-Roger 
+                                        standard errors and d.f.")), brk = "\n")
 
       } else if (x$p_calc %in% c("s", "Satterthwaite", "satterthwaite")) {
 
         cat("\n")
-        cat_wrap(italic$cyan("p values calculated using Satterthwaite
-                        d.f."), brk = "\n")
+        cat_wrap(style_italic(col_cyan("p values calculated using Satterthwaite
+                                      d.f.")), brk = "\n")
 
       } else if (x$p_calc == "manual") {
 
-        cat(italic("\nNote: p values calculated based on user-defined d.f. ="),
+        cat(style_italic("\nNote: p values calculated based on user-defined d.f. ="),
             x$df, "\n")
 
       }
@@ -2069,7 +2058,7 @@ print.summ.merMod <- function(x, ...) {
     }
 
     if (x$re.table == TRUE) {
-      cat(underline("\nRANDOM EFFECTS:\n"))
+      cat(style_underline("\nRANDOM EFFECTS:\n"))
       rtable <- round_df_char(j$rcoeftable, digits = x$digits, na_vals = "")
       #rownames(rtable) <- rep("", times = nrow(rtable))
       # print(rtable, row.names = FALSE)
@@ -2079,7 +2068,7 @@ print.summ.merMod <- function(x, ...) {
     }
 
     if (x$groups.table == TRUE) {
-      cat(underline("\nGrouping variables:\n"))
+      cat(style_underline("\nGrouping variables:\n"))
       gtable <- round_df_char(j$gvars, digits = x$digits, na_vals = "")
       gtable[, "# groups"] <- as.integer(gtable[, "# groups"])
       #rownames(gtable) <- rep("", times = nrow(gtable))
@@ -2098,12 +2087,7 @@ print.summ.merMod <- function(x, ...) {
 }
 
 #' @rdname knit_print.summ
-#' @rawNamespace 
-#' if (getRversion() >= "3.6.0") {
-#'   S3method(knitr::knit_print, summ.merMod)
-#' } else {
-#'   export(knit_print.summ.merMod)
-#' }
+#' @exportS3Method knitr::knit_print
 
 knit_print.summ.merMod <- function(x, options = NULL, ...) {
 
