@@ -57,9 +57,9 @@
 #'   such situations.
 #'
 #'   This theme was created with inspiration from Rudolf Cardinal's
-#'   \href{http://egret.psychol.cam.ac.uk/statistics/R/graphs2.html}{code}, which
-#'   required updating for newer versions of \code{ggplot2} and adaptations for
-#'   APA style.
+#'   \href{https://web.archive.org/web/20220616072522/http://egret.psychol.cam.ac.uk/statistics/R/graphs2.html}{code}, 
+#'   which required updating for newer versions of \code{ggplot2} and 
+#'   adaptations for APA style.
 #'
 #' @author Jacob Long \email{jacob.long@@sc.edu}
 #'
@@ -106,7 +106,7 @@ theme_apa <- function(legend.pos = "right", legend.use.title = FALSE,
     strip.text.x = ggplot2::element_text(size = facet.title.size), # facet labs
     strip.text.y = ggplot2::element_text(size = facet.title.size),
     # facet titles
-    strip.background = ggplot2::element_rect(colour = "white", fill = "white"),
+    strip.background = ggplot2::element_rect(colour = NA, fill = NA),
     panel.background = ggplot2::element_rect(fill = "white"),
     plot.title.position = "panel",
     # complete = TRUE
